@@ -3,7 +3,6 @@ function (trt,number=1,seed=0,kinds="Super-Duper")
 {
 r <- length(trt)
 if(seed != 0) set.seed(seed,kinds)
-m <- sample(trt, r)
 a <- 1:(r * r)
 dim(a) <- c(r, r)
 for (i in 1:r) {
@@ -14,20 +13,13 @@ k <- i + j - r - 1
 a[i, j] <- k
 }
 }
-
-# Asigna valores de fila y columna
-fila <- rep(0, r * r)
-columna <- fila
-trat <- fila
-plots <- 0
-for (i in 1:r) {
-for (j in 1:r) {
-plots <- plots + 1
-fila[plots] <- i
-columna[plots] <- j
-trat[plots] <- m[a[i, j]]
-}
-}
+m<-sample(2:r,r-1)
+a<-a[c(1,m),]
+m<-sample(1:r,r)
+a<-a[,m]
+trat<-trt[a]
+columna<- rep(gl(r,1),r)
+fila <- gl(r,r)
 plots <- number+1:length(trat)-1
 book<-data.frame(plots,row=as.factor(fila),col=as.factor(columna),
 trat=as.factor(trat))
