@@ -1,5 +1,5 @@
-#setwd("d:/statistics/agricolae/R")
-setwd("f:/statistics/agricolae/R")
+setwd("d:/statistics/agricolae/R")
+#setwd("f:/statistics/agricolae/R")
 library(agricolae)
 data(CIC)
 data(ComasOxapampa)
@@ -25,41 +25,34 @@ data(natives)
 data(paracsho)
 data(plots)
 data(potato)
-data(precipitation)
 data(ralstonia)
 data(rice)
 data(sinRepAmmi)
 data(soil)
-data(stable)
 data(sweetpotato)
 data(trees)
 data(wild)
 
-source("alpha01.R")
 source("AMMI.contour.R")
 source("AMMI.R")
-source("audpc.abs.R")
-source("audpc.rel.R")
+source("audpc.R")
 source("bar.err.R")
 source("bar.group.R")
 source("BIB.test.R")
 source("carolina.R")
 source("coeff.diana.R")
-source("cor.matrix.R")
-source("cor.mv.R")
-source("cor.vector.R")
 source("correl.R")
+source("correlation.R")
 source("cv.model.R")
 source("cv.similarity.R")
-source("decimals.R")
 source("delete.na.R")
 source("design.ab.R")
-source("design.bib.r")
+source("design.alpha.R")
+source("design.bib.R")
 source("design.crd.R")
 source("design.graeco.R")
 source("design.lsd.R")
 source("design.rcbd.R")
-source("dimnames.order.R")
 source("durbin.test.R")
 source("fact.nk.R")
 source("friedman.test.R")
@@ -85,7 +78,6 @@ source("ojiva.freq.R")
 source("order.group.R")
 source("order.stat.R")
 source("path.analysis.R")
-source("plot.disc.R")
 source("polygon.freq.R")
 source("random.ab.R")
 source("reg.homog.R")
